@@ -2,13 +2,22 @@ use rowan::TextRange;
 use squawk_syntax::ast::{self, AstNode};
 
 use crate::binder::{self, extract_string_literal};
-use crate::resolve::{resolve_function_info, resolve_table_info, resolve_type_info};
+use crate::resolve::{
+    resolve_aggregate_info, resolve_function_info, resolve_materialized_view_info,
+    resolve_procedure_info, resolve_table_info, resolve_type_info, resolve_view_info,
+};
 
 #[derive(Debug)]
 pub enum DocumentSymbolKind {
+    Schema,
     Table,
+    View,
+    MaterializedView,
     Function,
+    Aggregate,
+    Procedure,
     Type,
+    Enum,
     Column,
     Variant,
 }
@@ -32,6 +41,11 @@ pub fn document_symbols(file: &ast::SourceFile) -> Vec<DocumentSymbol> {
 
     for stmt in file.stmts() {
         match stmt {
+            ast::Stmt::CreateSchema(create_schema) => {
+                if let Some(symbol) = create_schema_symbol(create_schema) {
+                    symbols.push(symbol);
+                }
+            }
             ast::Stmt::CreateTable(create_table) => {
                 if let Some(symbol) = create_table_symbol(&binder, create_table) {
                     symbols.push(symbol);
@@ -42,11 +56,47 @@ pub fn document_symbols(file: &ast::SourceFile) -> Vec<DocumentSymbol> {
                     symbols.push(symbol);
                 }
             }
+            ast::Stmt::CreateAggregate(create_aggregate) => {
+                if let Some(symbol) = create_aggregate_symbol(&binder, create_aggregate) {
+                    symbols.push(symbol);
+                }
+            }
+            ast::Stmt::CreateProcedure(create_procedure) => {
+                if let Some(symbol) = create_procedure_symbol(&binder, create_procedure) {
+                    symbols.push(symbol);
+                }
+            }
             ast::Stmt::CreateType(create_type) => {
                 if let Some(symbol) = create_type_symbol(&binder, create_type) {
                     symbols.push(symbol);
                 }
             }
+            ast::Stmt::CreateView(create_view) => {
+                if let Some(symbol) = create_view_symbol(&binder, create_view) {
+                    symbols.push(symbol);
+                }
+            }
+            ast::Stmt::CreateMaterializedView(create_view) => {
+                if let Some(symbol) = create_materialized_view_symbol(&binder, create_view) {
+                    symbols.push(symbol);
+                }
+            }
+            ast::Stmt::Select(select) => {
+                symbols.extend(cte_table_symbols(select));
+            }
+            ast::Stmt::SelectInto(select_into) => {
+                symbols.extend(cte_table_symbols(select_into));
+            }
+            ast::Stmt::Insert(insert) => {
+                symbols.extend(cte_table_symbols(insert));
+            }
+            ast::Stmt::Update(update) => {
+                symbols.extend(cte_table_symbols(update));
+            }
+            ast::Stmt::Delete(delete) => {
+                symbols.extend(cte_table_symbols(delete));
+            }
+
             _ => {}
         }
     }
@@ -54,6 +104,74 @@ pub fn document_symbols(file: &ast::SourceFile) -> Vec<DocumentSymbol> {
     symbols
 }
 
+fn cte_table_symbols(stmt: impl ast::HasWithClause) -> Vec<DocumentSymbol> {
+    let Some(with_clause) = stmt.with_clause() else {
+        return vec![];
+    };
+
+    with_clause
+        .with_tables()
+        .filter_map(create_cte_table_symbol)
+        .collect()
+}
+
+fn create_cte_table_symbol(with_table: ast::WithTable) -> Option<DocumentSymbol> {
+    let name_node = with_table.name()?;
+    let name = name_node.syntax().text().to_string();
+
+    let full_range = with_table.syntax().text_range();
+    let focus_range = name_node.syntax().text_range();
+
+    let mut children = vec![];
+    if let Some(column_list) = with_table.column_list() {
+        for column in column_list.columns() {
+            if let Some(column_symbol) = create_column_symbol(column) {
+                children.push(column_symbol);
+            }
+        }
+    }
+
+    Some(DocumentSymbol {
+        name,
+        detail: None,
+        kind: DocumentSymbolKind::Table,
+        full_range,
+        focus_range,
+        children,
+    })
+}
+
+fn create_schema_symbol(create_schema: ast::CreateSchema) -> Option<DocumentSymbol> {
+    let (name, focus_range) = if let Some(name_node) = create_schema.name() {
+        (
+            name_node.syntax().text().to_string(),
+            name_node.syntax().text_range(),
+        )
+    } else if let Some(schema_name_ref) = create_schema
+        .schema_authorization()
+        .and_then(|authorization| authorization.role())
+        .and_then(|role| role.name_ref())
+    {
+        (
+            schema_name_ref.syntax().text().to_string(),
+            schema_name_ref.syntax().text_range(),
+        )
+    } else {
+        return None;
+    };
+
+    let full_range = create_schema.syntax().text_range();
+
+    Some(DocumentSymbol {
+        name,
+        detail: None,
+        kind: DocumentSymbolKind::Schema,
+        full_range,
+        focus_range,
+        children: vec![],
+    })
+}
+
 fn create_table_symbol(
     binder: &binder::Binder,
     create_table: ast::CreateTable,
@@ -89,6 +207,72 @@ fn create_table_symbol(
     })
 }
 
+fn create_view_symbol(
+    binder: &binder::Binder,
+    create_view: ast::CreateView,
+) -> Option<DocumentSymbol> {
+    let path = create_view.path()?;
+    let segment = path.segment()?;
+    let name_node = segment.name()?;
+
+    let (schema, view_name) = resolve_view_info(binder, &path)?;
+    let name = format!("{}.{}", schema.0, view_name);
+
+    let full_range = create_view.syntax().text_range();
+    let focus_range = name_node.syntax().text_range();
+
+    let mut children = vec![];
+    if let Some(column_list) = create_view.column_list() {
+        for column in column_list.columns() {
+            if let Some(column_symbol) = create_column_symbol(column) {
+                children.push(column_symbol);
+            }
+        }
+    }
+
+    Some(DocumentSymbol {
+        name,
+        detail: None,
+        kind: DocumentSymbolKind::View,
+        full_range,
+        focus_range,
+        children,
+    })
+}
+
+fn create_materialized_view_symbol(
+    binder: &binder::Binder,
+    create_view: ast::CreateMaterializedView,
+) -> Option<DocumentSymbol> {
+    let path = create_view.path()?;
+    let segment = path.segment()?;
+    let name_node = segment.name()?;
+
+    let (schema, view_name) = resolve_materialized_view_info(binder, &path)?;
+    let name = format!("{}.{}", schema.0, view_name);
+
+    let full_range = create_view.syntax().text_range();
+    let focus_range = name_node.syntax().text_range();
+
+    let mut children = vec![];
+    if let Some(column_list) = create_view.column_list() {
+        for column in column_list.columns() {
+            if let Some(column_symbol) = create_column_symbol(column) {
+                children.push(column_symbol);
+            }
+        }
+    }
+
+    Some(DocumentSymbol {
+        name,
+        detail: None,
+        kind: DocumentSymbolKind::MaterializedView,
+        full_range,
+        focus_range,
+        children,
+    })
+}
+
 fn create_function_symbol(
     binder: &binder::Binder,
     create_function: ast::CreateFunction,
@@ -113,6 +297,54 @@ fn create_function_symbol(
     })
 }
 
+fn create_aggregate_symbol(
+    binder: &binder::Binder,
+    create_aggregate: ast::CreateAggregate,
+) -> Option<DocumentSymbol> {
+    let path = create_aggregate.path()?;
+    let segment = path.segment()?;
+    let name_node = segment.name()?;
+
+    let (schema, aggregate_name) = resolve_aggregate_info(binder, &path)?;
+    let name = format!("{}.{}", schema.0, aggregate_name);
+
+    let full_range = create_aggregate.syntax().text_range();
+    let focus_range = name_node.syntax().text_range();
+
+    Some(DocumentSymbol {
+        name,
+        detail: None,
+        kind: DocumentSymbolKind::Aggregate,
+        full_range,
+        focus_range,
+        children: vec![],
+    })
+}
+
+fn create_procedure_symbol(
+    binder: &binder::Binder,
+    create_procedure: ast::CreateProcedure,
+) -> Option<DocumentSymbol> {
+    let path = create_procedure.path()?;
+    let segment = path.segment()?;
+    let name_node = segment.name()?;
+
+    let (schema, procedure_name) = resolve_procedure_info(binder, &path)?;
+    let name = format!("{}.{}", schema.0, procedure_name);
+
+    let full_range = create_procedure.syntax().text_range();
+    let focus_range = name_node.syntax().text_range();
+
+    Some(DocumentSymbol {
+        name,
+        detail: None,
+        kind: DocumentSymbolKind::Procedure,
+        full_range,
+        focus_range,
+        children: vec![],
+    })
+}
+
 fn create_type_symbol(
     binder: &binder::Binder,
     create_type: ast::CreateType,
@@ -145,7 +377,11 @@ fn create_type_symbol(
     Some(DocumentSymbol {
         name,
         detail: None,
-        kind: DocumentSymbolKind::Type,
+        kind: if create_type.variant_list().is_some() {
+            DocumentSymbolKind::Enum
+        } else {
+            DocumentSymbolKind::Type
+        },
         full_range,
         focus_range,
         children,
@@ -226,9 +462,15 @@ mod tests {
 
     fn symbol_to_group<'a>(symbol: &DocumentSymbol, sql: &'a str) -> Group<'a> {
         let kind = match symbol.kind {
+            DocumentSymbolKind::Schema => "schema",
             DocumentSymbolKind::Table => "table",
+            DocumentSymbolKind::View => "view",
+            DocumentSymbolKind::MaterializedView => "materialized view",
             DocumentSymbolKind::Function => "function",
+            DocumentSymbolKind::Aggregate => "aggregate",
+            DocumentSymbolKind::Procedure => "procedure",
             DocumentSymbolKind::Type => "type",
+            DocumentSymbolKind::Enum => "enum",
             DocumentSymbolKind::Column => "column",
             DocumentSymbolKind::Variant => "variant",
         };
@@ -326,6 +568,36 @@ create table users (
         ");
     }
 
+    #[test]
+    fn create_schema() {
+        assert_snapshot!(symbols("
+create schema foo;
+"), @r"
+        info: schema: foo
+          ╭▸ 
+        2 │ create schema foo;
+          │ ┬─────────────┯━━
+          │ │             │
+          │ │             focus range
+          ╰╴full range
+        ");
+    }
+
+    #[test]
+    fn create_schema_authorization() {
+        assert_snapshot!(symbols("
+create schema authorization foo;
+"), @r"
+        info: schema: foo
+          ╭▸ 
+        2 │ create schema authorization foo;
+          │ ┬───────────────────────────┯━━
+          │ │                           │
+          │ │                           focus range
+          ╰╴full range
+        ");
+    }
+
     #[test]
     fn create_function() {
         assert_snapshot!(
@@ -342,6 +614,54 @@ create table users (
         );
     }
 
+    #[test]
+    fn create_materialized_view() {
+        assert_snapshot!(
+            symbols("create materialized view reports as select 1;"),
+            @r"
+        info: materialized view: public.reports
+          ╭▸ 
+        1 │ create materialized view reports as select 1;
+          │ ┬────────────────────────┯━━━━━━────────────
+          │ │                        │
+          │ │                        focus range
+          ╰╴full range
+        "
+        );
+    }
+
+    #[test]
+    fn create_aggregate() {
+        assert_snapshot!(
+            symbols("create aggregate myavg(int) (sfunc = int4_avg_accum, stype = _int8);"),
+            @r"
+        info: aggregate: public.myavg
+          ╭▸ 
+        1 │ create aggregate myavg(int) (sfunc = int4_avg_accum, stype = _int8);
+          │ ┬────────────────┯━━━━─────────────────────────────────────────────
+          │ │                │
+          │ │                focus range
+          ╰╴full range
+        "
+        );
+    }
+
+    #[test]
+    fn create_procedure() {
+        assert_snapshot!(
+            symbols("create procedure hello() language sql as $$ select 1; $$;"),
+            @r"
+        info: procedure: public.hello
+          ╭▸ 
+        1 │ create procedure hello() language sql as $$ select 1; $$;
+          │ ┬────────────────┯━━━━──────────────────────────────────
+          │ │                │
+          │ │                focus range
+          ╰╴full range
+        "
+        );
+    }
+
     #[test]
     fn multiple_symbols() {
         assert_snapshot!(symbols("
@@ -424,7 +744,7 @@ create function my_schema.hello() returns void as $$ select 1; $$ language sql;
         assert_snapshot!(
             symbols("create type status as enum ('active', 'inactive');"),
             @r"
-        info: type: public.status
+        info: enum: public.status
           ╭▸ 
         1 │ create type status as enum ('active', 'inactive');
           │ ┬───────────┯━━━━━───────────────────────────────
@@ -501,7 +821,7 @@ create function my_schema.hello() returns void as $$ select 1; $$ language sql;
         assert_snapshot!(
             symbols("create type myschema.status as enum ('active', 'inactive');"),
             @r"
-        info: type: myschema.status
+        info: enum: myschema.status
           ╭▸ 
         1 │ create type myschema.status as enum ('active', 'inactive');
           │ ┬────────────────────┯━━━━━───────────────────────────────
@@ -526,7 +846,7 @@ create function my_schema.hello() returns void as $$ select 1; $$ language sql;
         assert_snapshot!(
             symbols("create type priority as enum ('low', 'medium', 'high', 'urgent');"),
             @r"
-        info: type: public.priority
+        info: enum: public.priority
           ╭▸ 
         1 │ create type priority as enum ('low', 'medium', 'high', 'urgent');
           │ ┬───────────┯━━━━━━━────────────────────────────────────────────
@@ -559,4 +879,64 @@ create function my_schema.hello() returns void as $$ select 1; $$ language sql;
     fn non_create_statements() {
         symbols_not_found("select * from users;")
     }
+
+    #[test]
+    fn cte_table() {
+        assert_snapshot!(
+            symbols("
+with recent_users as (
+  select id, email as user_email
+  from users
+)
+select * from recent_users;
+"),
+            @r"
+        info: table: recent_users
+          ╭▸ 
+        2 │   with recent_users as (
+          │        │━━━━━━━━━━━
+          │        │
+          │ ┌──────focus range
+          │ │
+        3 │ │   select id, email as user_email
+        4 │ │   from users
+        5 │ │ )
+          ╰╴└─┘ full range
+        "
+        );
+    }
+
+    #[test]
+    fn cte_table_with_column_list() {
+        assert_snapshot!(
+            symbols("
+with t(a, b, c) as (
+  select 1, 2, 3
+)
+select * from t;
+"),
+            @r"
+        info: table: t
+          ╭▸ 
+        2 │   with t(a, b, c) as (
+          │        ━ focus range
+          │ ┌──────┘
+          │ │
+        3 │ │   select 1, 2, 3
+        4 │ │ )
+          │ └─┘ full range
+          │
+          ⸬  
+        2 │   with t(a, b, c) as (
+          │          ┯  ┯  ┯
+          │          │  │  │
+          │          │  │  full range for `column: c`
+          │          │  │  focus range
+          │          │  full range for `column: b`
+          │          │  focus range
+          │          full range for `column: a`
+          ╰╴         focus range
+        "
+        );
+    }
 }
