@@ -178,20 +178,37 @@ fn handle_goto_definition(
     let line_index = LineIndex::new(content);
     let offset = lsp_utils::offset(&line_index, position).unwrap();
 
-    let range = goto_definition(file, offset);
+    let ranges = goto_definition(file, offset);
 
-    let result = match range {
-        Some(target_range) => {
-            debug_assert!(
-                !target_range.contains(offset),
-                "Our target destination range must not include the source range otherwise go to def won't work in vscode."
-            );
-            GotoDefinitionResponse::Scalar(Location {
-                uri: uri.clone(),
-                range: lsp_utils::range(&line_index, target_range),
-            })
-        }
-        None => GotoDefinitionResponse::Array(vec![]),
+    let result = if ranges.is_empty() {
+        GotoDefinitionResponse::Array(vec![])
+    } else if ranges.len() == 1 {
+        // TODO: can we just always use the array response?
+        let target_range = ranges[0];
+        debug_assert!(
+            !target_range.contains(offset),
+            "Our target destination range must not include the source range otherwise go to def won't work in vscode."
+        );
+        GotoDefinitionResponse::Scalar(Location {
+            uri: uri.clone(),
+            range: lsp_utils::range(&line_index, target_range),
+        })
+    } else {
+        GotoDefinitionResponse::Array(
+            ranges
+                .into_iter()
+                .map(|target_range| {
+                    debug_assert!(
+                        !target_range.contains(offset),
+                        "Our target destination range must not include the source range otherwise go to def won't work in vscode."
+                    );
+                    Location {
+                        uri: uri.clone(),
+                        range: lsp_utils::range(&line_index, target_range),
+                    }
+                })
+                .collect(),
+        )
     };
 
     let resp = Response {
@@ -335,9 +352,15 @@ fn handle_document_symbol(
             name: sym.name,
             detail: sym.detail,
             kind: match sym.kind {
+                DocumentSymbolKind::Schema => SymbolKind::NAMESPACE,
                 DocumentSymbolKind::Table => SymbolKind::STRUCT,
+                DocumentSymbolKind::View => SymbolKind::STRUCT,
+                DocumentSymbolKind::MaterializedView => SymbolKind::STRUCT,
                 DocumentSymbolKind::Function => SymbolKind::FUNCTION,
+                DocumentSymbolKind::Aggregate => SymbolKind::FUNCTION,
+                DocumentSymbolKind::Procedure => SymbolKind::FUNCTION,
                 DocumentSymbolKind::Type => SymbolKind::CLASS,
+                DocumentSymbolKind::Enum => SymbolKind::ENUM,
                 DocumentSymbolKind::Column => SymbolKind::FIELD,
                 DocumentSymbolKind::Variant => SymbolKind::ENUM_MEMBER,
             },
