@@ -3,16 +3,23 @@
 use crate::ast;
 use crate::ast::{AstNode, support};
 
-pub trait HasName: AstNode {
-    fn name(&self) -> Option<ast::Name> {
+pub trait NameLike: AstNode {}
+
+pub trait HasCreateTable: AstNode {
+    #[inline]
+    fn path(&self) -> Option<ast::Path> {
+        support::child(self.syntax())
+    }
+
+    #[inline]
+    fn table_arg_list(&self) -> Option<ast::TableArgList> {
         support::child(self.syntax())
     }
 }
 
-pub trait NameLike: AstNode {}
-
-pub trait HasArgList: AstNode {
-    fn arg_list(&self) -> Option<ast::ArgList> {
+pub trait HasWithClause: AstNode {
+    #[inline]
+    fn with_clause(&self) -> Option<ast::WithClause> {
         support::child(self.syntax())
     }
 }
@@ -22,15 +29,3 @@ pub trait HasParamList: AstNode {
         support::child(self.syntax())
     }
 }
-
-pub trait HasIfExists: AstNode {
-    fn if_exists(&self) -> Option<ast::IfExists> {
-        support::child(self.syntax())
-    }
-}
-
-pub trait HasIfNotExists: AstNode {
-    fn if_not_exists(&self) -> Option<ast::IfNotExists> {
-        support::child(self.syntax())
-    }
-}
